/* Palette
#eeee99
#ede059    
#bcc98e    
#638270
#2b434f    
#0c2538    
*/

body {
    font-family: Trebuchet MS, Helvetica, Arial;
}   

#header {
    margin-bottom:20px;
    background: #2b434f;
    border-bottom: 5px solid #638270;
}

#header ul {
    display: block;
    list-style: none;
    margin: 0;
    padding: 0;
}

#header ul li {
    height: 40px;
    float: left;
    margin: 20px 10px 0 0;
    padding: 0;
}

li {
    display: list-item;
    text-align: -webkit-match-parent;
}

.logo {
    font-weight: normal;
    color: white;
    text-decoration:none;
    font-size: 22px;
}

.logo em {
    font-style: normal;
    color: #CE2;
}

.searchinput {
    width: 500px;
}

.reslink {
    color: #12c;
    cursor: pointer;
    text-decoration: underline;
    font-size: 1.3em;
}

.tablink {
    color:#333;
}

